@@ -636,7 +636,8 @@ lmcovlatent <- function(S,X1=NULL,X2=NULL,yv=rep(1,nrow(S)),k,start=0,tol=10^-8,
     }
     if(k>2) {
       Ga = array(as.vector(Ga),c(nc2,k-1,k))
-      dimnames(Ga) = list(nameGa,logit=2:k,logit=1:k)
+      dimnames(Ga) = list(nameGa,"column (without the row)"=1:(k-1),
+                          "row (of the transition matrix)"=1:k)
     }else if(k==2){
       dimnames(Ga) = list(nameGa,logit=1:k)
     }
@@ -646,7 +647,8 @@ lmcovlatent <- function(S,X1=NULL,X2=NULL,yv=rep(1,nrow(S)),k,start=0,tol=10^-8,
         dimnames(seGa) = list(nameGa,logit=1:k)
       }else if(k>2){
         seGa = array(as.vector(sega),c(nc2,k-1,k))
-        dimnames(seGa) = list(nameGa,logit=2:k,logit=1:k)
+        dimnames(seGa) = list(nameGa,"column (without the row)"=1:(k-1),
+                              "row (of the transition matrix)"=1:k)
       }
     }
   }else if(param=="difflogit"){
